@@ -27,10 +27,11 @@ test_that("test create tool overrides export_shapes", {
   # exporting from saga as a file return the filename
   res <- saga$io_gdal$export_shapes(
     shapes = nc,
-    file = tempfile(fileext = ".shp")
+    file = tempfile(fileext = ".shp"),
+    format = "ESRI Shapefile"
   )
   
-  expect_type(res, "character")
+  testthat::expect_type(res, "character")
 })
 
 
@@ -39,7 +40,7 @@ test_that("test create tool overrides tpi_based_landform_classification", {
   testthat::skip_if(is.null(saga_search()))
   
   saga <- saga_gis(backend = "raster")
-  
+
   dem <- saga$grid_calculus$random_terrain()
   
   res <- saga$ta_morphometry$tpi_based_landform_classification(
@@ -49,6 +50,24 @@ test_that("test create tool overrides tpi_based_landform_classification", {
     radius_b_min = 0, 
     radius_b_max = 20
   )
+
+  expect_s4_class(res, "RasterLayer")
+})
+
+
+test_that("test create tool overrides topographic_position_index_tpi", {
+  testthat::skip_on_cran()
+  testthat::skip_if(is.null(saga_search()))
+  
+  saga <- saga_gis(backend = "raster")
+  
+  dem <- saga$grid_calculus$random_terrain()
+  
+  res <- saga$ta_morphometry$topographic_position_index_tpi(
+    dem = dem, 
+    radius_min = 0, 
+    radius_max = 100
+  )
   
   expect_s4_class(res, "RasterLayer")
 })
